@@ -119,55 +119,47 @@ for ingredient in PARAMS:
         ALL_PARAMS[param] = PARAMS[ingredient][param]
         if PARAMS[ingredient][param]["derivative"]:
             ALL_TRAINABLE_PARAMS[param] = PARAMS[ingredient][param]
-
 ALL_PARAMS_LIST = list(ALL_PARAMS.keys())
 ALL_TRAINABLE_PARAMS_LIST = list(ALL_TRAINABLE_PARAMS.keys())
 
 INITIALIZERS_NO_HYPE = {"zeros_initializer": {"keras": ["",
                                                         []],
-                                              "tf": ["tf.zeros_initializer",
-                                                     {"shape": "shape",
-                                                     "name": "name"}],
+                                              "tf": ["tf.zeros_initializer()",
+                                                     {"shape": "shape"}],
                                               "pytorch": ["torch.nn.init.zeros_",
                                                           {"tensor": "torch.empty(*shape)"}],
                                               "alex": ["zeros_initializer",
                                                        {"dtype": True,
-                                                        "shape": False,
-                                                        "name": True}]},
+                                                        "shape": False}]},
                         "ones_initializer": {"keras": ["",
                                                        []],
-                                             "tf": ["tf.ones_initializer",
-                                                    {"shape": "shape",
-                                                     "name": "name"}],
+                                             "tf": ["tf.ones_initializer()",
+                                                    {"shape": "shape"}],
                                              "pytorch": ["torch.nn.init.ones_",
                                                          {"tensor": "torch.empty(*shape)"}],
                                              "alex": ["ones_initializer",
                                                       {"dtype": True,
-                                                       "shape": False,
-                                                       "name": True}]}}
+                                                       "shape": False}]}}
 
 INITIALIZERS = {"he_uniform": {"keras": ["keras.initializers.he_uniform", []],
                                "tf": ["tf.keras.initializers.he_uniform(seed=seed)",
-                                      {"shape": "shape",
-                                       "name": "name"}],
+                                      {"shape": "shape"}],
                                "pytorch": ["torch.nn.init.kaiming_uniform",
                                            {"tensor": "torch.empty(*shape)"}],
                                "alex": ["he_uniform",
                                         {"dtype": True,
                                          "seed": True,
-                                         "shape": False,
-                                         "name": True}]},
+                                         "shape": False}]},
                 "xavier_uniform": {"keras": ["keras.initializers.glorot_uniform",
                                              {}],
                                    "tf": ["tf.keras.initializers.glorot_uniform(seed=seed)",
-                                          []],
+                                          {"shape": "shape"}],
                                    "pytorch": ["torch.nn.init.xavier_uniform_",
                                                {"tensor": "torch.empty(*shape)"}],
                                    "alex": ["xavier_uniform",
                                             {"dtype": True,
                                              "seed": True,
-                                             "shape": False,
-                                             "name": True}]}}
+                                             "shape": False}]}}
 
 ALL_INITIALIZERS = {**INITIALIZERS_NO_HYPE, **INITIALIZERS}
 
@@ -178,7 +170,6 @@ COMPONENTS = {"conv": {"tf": ["tf.nn.conv2d",
                                "padding": "padding",
                                "data_format": "'NHWC'",
                                "dilations": "dilation",
-                               "use_bias": "False",
                                "name": "name"}],
                        "keras": ["keras.layers.Conv2D", {}],
                        "pytorch": ["torch.nn.functional.conv2d",
@@ -294,7 +285,8 @@ DET_COMPONENTS_NO_HYPE = {"relu": {"tf": ["tf.nn.relu",
                                              "dtype": True,
                                              "name": True}]},
                           "softmax": {"tf": ["tf.nn.softmax",
-                                             {}],
+                                             {"logits": "inputs",
+                                              "name": "name"}],
                                       "pytorch": ["torch.nn.functional.softmax",
                                                   {"input": "inputs",
                                                    "dim": "None"}],
@@ -303,7 +295,8 @@ DET_COMPONENTS_NO_HYPE = {"relu": {"tf": ["tf.nn.relu",
                                                 "dtype": True,
                                                 "name": True}]},
                           "sigmoid": {"tf": ["tf.math.sigmoid",
-                                             {}],
+                                             {"x": "inputs",
+                                              "name": "name"}],
                                       "pytorch": ["torch.sigmoid",
                                                   {"input": "inputs"}],
                                       "alex": ["sigmoid",
@@ -312,7 +305,7 @@ DET_COMPONENTS_NO_HYPE = {"relu": {"tf": ["tf.nn.relu",
                                                 "name": True}]},
                           "flatten": {"tf": ["tf.reshape",
                                              {"tensor": "inputs",
-                                              "shape": "(-1, shape.prod())",
+                                              "shape": "(-1, tf.math.reduce_prod(tf.convert_to_tensor(shape)))",
                                               "name": "name"}],
                                       "keras": ["keras.layers.Flatten", []],
                                       "pytorch": ["torch.flatten",
@@ -364,7 +357,7 @@ LOSSES = {"cross_entropy": {"tf": ["tf.nn.softmax_cross_entropy_with_logits",
                                       "dtype": True,
                                       "training": False}]}}
 # TODO: bitwise, l2, mean_square
-REGULARIZERS = {"regularizer_l2": {"tf": ["coeff*sum(list(map(lambda x: tf.nn.l2_loss(x=trainable_params[x], name=name), inputs)))",
+REGULARIZERS = {"regularizer_l2": {"tf": ["coeff*sum(list(map(lambda x: tf.nn.l2_loss(t=trainable_params[x], name=name), inputs)))",
                                           {}],
                                    "pytorch": ["coeff*sum(list(map(lambda x: torch.norm(input=trainable_params[x]), inputs)))",
                                                {}],
@@ -405,7 +398,7 @@ OPTIMIZERS = {"adam": {"tf": ["tf.optimizers.Adam",
 LOSS_BLOCK = {**LOSSES, **REGULARIZERS}
 INGREDIENT_TYPES = {**DL_LAYERS, **LOSSES, **OPTIMIZERS, **INFERENCE}
 
-INPUTS = ("data", "label")
+INPUT_TYPES = ("data", "label")
 
 
 LEARNING_RATE_DECAY = {"exponential_decay": {"tf": ["tf.keras.optimizers.schedules.ExponentialDecay",
@@ -423,7 +416,8 @@ LEARNING_RATE_DECAY = {"exponential_decay": {"tf": ["tf.keras.optimizers.schedul
                                                       {"initial_learning_rate": True,
                                                        "decay_steps": True,
                                                        "decay_rate": True,
-                                                       "staircase": True
+                                                       "staircase": True,
+                                                       "optimizer": False
                                                       }]}} # FIXME
 SCHEDULER_BLOCK = {**LEARNING_RATE_DECAY}
 
@@ -505,7 +499,7 @@ COMPONENT = 'component'
 LOSS = 'loss'
 SOLVER = 'optimizers'
 TYPE = 'type'
-INPUT_COMPONENT = 'input_component'
+INPUTS = 'inputs'
 PARAMS_NETWORK = 'params_network'
 PARAMS_TRAINING = "params_training"
 PARAMS_LOSSES = 'params_losses'
