@@ -28,6 +28,7 @@ import rope
 from rope.base.project import Project
 from rope.refactor.inline import create_inline
 import warnings
+import traceback
 
 from alex.alex import core, const, node_interface, checkpoint, util
 from alex.alex.checkpoint import Checkpoint
@@ -188,17 +189,17 @@ class Ingredient(param_count.Ingredient):
         children = core.get_children(node["name"], annotated)
         args = dict()
         if node["input_nodes"] is not None:
-            input_component = _name_strs_to_names(node["input_nodes"])
-            if len(input_component) == 1:
-                input_component = input_component[0]
+            inputs = _name_strs_to_names(node["input_nodes"])
+            if len(inputs) == 1:
+                inputs = inputs[0]
         else:
-            input_component = None
+            inputs = None
 
         args[const.ALEX_ARG_INPUTS] = {"key": const.ALEX_ARG_INPUTS,
-                                       "value": input_component,
-                                       "ref": input_component,
+                                       "value": inputs,
+                                       "ref": inputs,
                                        "type": IDENTIFIER,
-                                       "str": value_to_kwarg_str("", input_component,
+                                       "str": value_to_kwarg_str("", inputs,
                                                                  literal=False)}
         args[const.ALEX_ARG_NAME] = {"key": const.ALEX_ARG_NAME,
                                      "value": _name_strs_to_names(node["name"]),
@@ -220,9 +221,11 @@ class Ingredient(param_count.Ingredient):
         return_symbol = _name_strs_to_names(node["name"])
 
         for child in children:
+            if child["value"] in args:
+                continue
             _arg = child["code"]["args"]
             for _key in _arg:
-                if _arg[_key]["type"] != VALUE:
+                if _arg[_key]["type"] == IDENTIFIER:
                     args = {**args, **{_key: _arg[_key]}}
             if child["code"]["type"] != VALUE:
                 if child["value"] in const.ALL_PARAMS:
@@ -243,15 +246,13 @@ class Ingredient(param_count.Ingredient):
                               "ref": child["name"],
                               "type": child["code"]["type"],
                               "str": child["code"]["str"]}
-                    if node["value"] in const.OPTIMIZERS and child["value"]=="decay":
-                        decay = deepcopy(_child)
-                        decay
-                    args = {**args,
-                            **{child["value"]: _child}}
-        if node["value"] in const.OPTIMIZERS and engine=="tf":
-            decay["key"] = "learning_rate"
-            args["learning_rate"] = decay
-
+                    if child["value"]=="decay":
+                        if engine == "tf":
+                            _child["key"] = "learning_rate"
+                            args["learning_rate"] = _child
+                    else:
+                        args = {**args,
+                                **{child["value"]: _child}}
         node = cache_fn(node,
                         node["value"],
                         args,
@@ -267,8 +268,6 @@ class Regularizer(param_count.Ingredient):
         super().__init__(*args, **kwargs)
 
     def generate_code(self, node, annotated, engine):
-        if node["type"] != "ingredient":
-            return None
         children = core.get_children(node["name"], annotated)
         args = dict()
         args[const.ALEX_ARG_INPUTS] = {"key": const.ALEX_ARG_INPUTS,
@@ -293,7 +292,7 @@ class Regularizer(param_count.Ingredient):
         for child in children:
             _arg = child["code"]["args"]
             for _key in _arg:
-                if _arg[_key]["type"] != VALUE:
+                if _arg[_key]["type"] == IDENTIFIER:
                     args = {**args, **{_key: _arg[_key]}}
             if child["code"]["type"] != VALUE:
                 if child["value"] in const.ALL_PARAMS:
@@ -590,8 +589,6 @@ def nodes(node):
         value = "ingredient"
     elif node["value"] in const.SCHEDULER_BLOCK:
         value = FUNCTION
-
-    # print(value, node["name"], "********************************")
     _nodes = {"ingredient": Ingredient,
               "recipe": Recipe,
               "initializer_fn": Initializer,
@@ -647,7 +644,7 @@ class CodeGen(param_count.ParamCount):
                        "optimizer": const.OPTIMIZER_BLOCK,
                        "loss": const.LOSS_BLOCK,
                        "scheduler": const.SCHEDULER_BLOCK,
-                       "data": const.INPUTS}
+                       "data": const.INPUT_TYPES}
         if engine == "tf":
             self.blocks["optimizer"] = {**self.blocks["optimizer"],
                                         **self.blocks["scheduler"]}
@@ -695,19 +692,24 @@ class CodeGen(param_count.ParamCount):
         if "block" in node and node["block"] is not None:
             block = node["block"]
         else:
-            _component_ = core.get_ancestor_ingredient_node(node,
-                                                            self.components,
-                                                            self.annotated,
-                                                            "value")
-            _param_ = core.get_ancestor_param_node(node,
-                                                   self.annotated,
-                                                   "value")
-            if _param_ is not None:
-                fn = _param_
-            elif _component_ is not None:
-                fn = _component_
             block = list(filter(lambda x: fn in self.blocks[x],
-                                self.blocks))[0]
+                                self.blocks))
+            if len(block) != 0:
+                block = block[0]
+            else:
+
+                _component_ = core.get_ancestor_ingredient_node(node,
+                                                                self.annotated,
+                                                                "value")
+                _param_ = core.get_ancestor_param_node(node,
+                                                       self.annotated,
+                                                       "value")
+                if _param_ is not None:
+                    fn = _param_
+                elif _component_ is not None:
+                    fn = _component_
+                block = list(filter(lambda x: fn in self.blocks[x],
+                                    self.blocks))[0]
         return block
 
     @staticmethod
@@ -740,6 +742,8 @@ class CodeGen(param_count.ParamCount):
         for fn in self.blocks[block]:
             component = self.blocks[block][fn]
             try:
+                if "alex" not in component:
+                    continue
                 src_fn = self.get_src_fn(component)
                 src_args_str = self.get_src_args_str(component)
                 trg_fn = self.get_trg_fn(component, self.engine)
@@ -753,9 +757,8 @@ class CodeGen(param_count.ParamCount):
                 self.inline_index_translation.append(src_fn)
 
             except Exception as error:
-                # print(error)
-                # print("%s not implemented" % fn)
-                pass
+                traceback.print_exc()
+                print("%s not implemented" % fn)
 
     def cache_param_translation(self):
         # Generate transltion for shape function
@@ -827,19 +830,18 @@ class CodeGen(param_count.ParamCount):
                         self.alex_code[block].append(node["code"]["extra"])
 
         except Exception as err:
-            # print(err)
-            # pprint(node)
-            raise
+            traceback.print_exc()
         return node
 
     def generate_python(self):
         self.annotate_tree()
         boiler_str = self.cache_boiler_plate()
 
+        param_args = ["ckpt=None"] # if self.load else []
         param_str = self.get_dl_code(block="param",
                                      fn_name="get_trainable_params",
                                      return_str="trainable_params",
-                                     manual_args=["ckpt"],
+                                     manual_args=param_args,
                                      prefix="trainable_params = dict()\n")
         loss_str = self.get_dl_code(block="loss",
                                     fn_name="get_loss",
@@ -873,9 +875,9 @@ class CodeGen(param_count.ParamCount):
                                self.filepaths[block])
         if prefix is not None:
             write_list_to_file(prefix, self.filepaths[block])
+
         write_list_to_file(self.alex_inline[block], self.filepaths[block])
         write_list_to_file(self.alex_code[block], self.filepaths[block])
-
         filename = self.filepaths[block].split("/")[-1]
         dirname = "/".join(self.filepaths[block].split("/")[:-1])
         with warnings.catch_warnings():
